==> myfaces-tobago-3.1.0-source-release.zip: tobago-3.1.0/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/behavior/AttachedStateWrapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.behavior;

import java.io.Serializable;

// todo: clean up (is a copy of MyFaces, but not all stuff is refactored)

class AttachedStateWrapper implements Serializable {

  private static final long serialVersionUID = 4948301780259917764L;

  private Class<?> clazz;
  private Object wrappedStateObject;

  /**
   * @param clazz              null means wrappedStateObject is a List of state objects
   */
  public AttachedStateWrapper(Class<?> clazz, Object wrappedStateObject) {
    if (wrappedStateObject != null && !(wrappedStateObject instanceof Serializable)) {
      throw new IllegalArgumentException("Attached state for Object of type " + clazz + " (Class "
          + wrappedStateObject.getClass().getName() + ") is not serializable");
    }
    this.clazz = clazz;
    this.wrappedStateObject = wrappedStateObject;
  }

  public Class<?> getClazz() {
    return clazz;
  }

  public Object getWrappedStateObject() {
    return wrappedStateObject;
  }
}

==> myfaces-tobago-6.9.1-source-release.zip: tobago-6.9.1/tobago-core/src/main/java/org/apache/myfaces/tobago/internal/behavior/AttachedStateWrapper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.myfaces.tobago.internal.behavior;

import java.io.Serial;
import java.io.Serializable;

// todo: clean up (is a copy of MyFaces, but not all stuff is refactored)

class AttachedStateWrapper implements Serializable {

  @Serial
  private static final long serialVersionUID = 4948301780259917764L;

  private Class<?> clazz;
  private Object wrappedStateObject;

  /**
   * @param clazz null means wrappedStateObject is a List of state objects
   */
  AttachedStateWrapper(final Class<?> clazz, final Object wrappedStateObject) {
    if (wrappedStateObject != null && !(wrappedStateObject instanceof Serializable)) {
      throw new IllegalArgumentException("Attached state for Object of type " + clazz + " (Class "
          + wrappedStateObject.getClass().getName() + ") is not serializable");
    }
    this.clazz = clazz;
    this.wrappedStateObject = wrappedStateObject;
  }

  public Class<?> getClazz() {
    return clazz;
  }

  Object getWrappedStateObject() {
    return wrappedStateObject;
  }
}
